@@ -60,7 +60,12 @@ func (n *NodeGroupService) Normalize(ctx context.Context, nodePools []api.NodePo
 			if ng.LaunchTemplate == nil && ng.InstanceType == "" && len(ng.InstanceTypes) == 0 && ng.InstanceSelector.IsZero() {
 				ng.InstanceType = api.DefaultNodeType
 			}
-			hasNativeAMIFamilySupport := ng.AMIFamily == api.NodeImageFamilyAmazonLinux2 || ng.AMIFamily == api.NodeImageFamilyBottlerocket || api.IsWindowsImage(ng.AMIFamily)
+			hasNativeAMIFamilySupport :=
+				ng.AMIFamily == api.NodeImageFamilyAmazonLinux2023 ||
+					ng.AMIFamily == api.NodeImageFamilyAmazonLinux2 ||
+					ng.AMIFamily == api.NodeImageFamilyBottlerocket ||
+					api.IsWindowsImage(ng.AMIFamily)
+
 			if !hasNativeAMIFamilySupport && !api.IsAMI(ng.AMI) {
 				if err := ResolveAMI(ctx, n.provider, clusterConfig.Metadata.Version, np); err != nil {
 					return err
